*==================================================================================================
*
*This should be used after having prepared data, see preparing_data.do
*This Do-File creates the summary statistics
*Used database: mainly database_balanced.dta
*Output : descriptive statistics tables, maps and graphic
*
*===================================================================================================

			********0*Install the package********
ssc install geonear //nearest neighbors
ssc install geodist //need for geonear
ssc install spmap // nice visualization of spatial data on a map
ssc install shp2dta // needed to extract the data from a shp file
ssc install mif2dta // needed for spmap
ssc install spmat // create and manage spatial-weighting matrix objects
net install xsmle, all from(http://www.econometrics.it/stata) // spatial econometrics models
ssc install missings //managing missings
ssc install ivreg2, replace //instrumental variable regression, needed for xtivreg2
ssc install xtivreg2 //instrumental variable regression in case of panel data
ssc install outreg2 //clean and nice output tables



			********1*Preliminary Work********
clear all
capture log close
use "/home/david/MEGA/Uni/Masterarbeit/Data/database_balanced.dta"
save "/home/david/MEGA/Uni/Masterarbeit/Desciptive Statistics/database.dta", replace
save "/home/david/MEGA/Uni/Masterarbeit/Desciptive Statistics/database_before_summary.dta", replace
clear
use "/home/david/MEGA/Uni/Masterarbeit/Data/database_balanced.dta"
replace ftefirst = 0 if ftefirst == . & years != 2015 //undo the heckman correction if already done
replace ftesecond = 0 if ftesecond == . & years != 2015
*END





			********2*Depend Variables Descr. Statistics********

cd "/home/david/MEGA/Uni/Masterarbeit/Desciptive Statistics/"
order id municipalities canton ftetotal ftefirst ftesecond ftethird ftemicro ftesmall ftemedium ftelarge firmstotal firmsfirst firmssecond firmsthird firmsmicro firmssmall firmsmedium firmslarge jobstotal jobsfirst jobssecond jobsthird jobsmicro jobssmall jobsmedium jobslarge
set more off
set matsize 8000
foreach var of varlist ftetotal-logftelarge { // replace BS and GL by missings if not already done
	replace `var' = . if canton == "BS" | canton == "GL"
}
summarize ftetotal ftefirst ftesecond ftethird ftemicro ftesmall ftemedium ftelarge firmstotal firmsfirst firmssecond firmsthird firmsmicro firmssmall firmsmedium firmslarge jobstotal jobsfirst jobssecond jobsthird jobsmicro jobssmall jobsmedium jobslarge
outreg2 using summary_dependent.doc, replace sum(log) keep(fte* firmstotal firmsfirst firmssecond firmsthird) title(Descriptive Statistics for dependent variables and its variations) addnote("Note:",)
*END 2






			********3*Independent Variable Descr. Statistics********
cd "/home/david/MEGA/Uni/Masterarbeit/Desciptive Statistics/"
capture drop if years == 2015
order id municipalities canton incomerateidx firmsrateidx unemployment wage under20 old foreigners leftstrength cinema university language metropolitan fte* firms* jobs*
set more off
set matsize 8000
foreach var of varlist ftetotal-logftelarge { // replace BS and GL by missings if not already done
	replace `var' = . if canton == "BS" | canton == "GL"
}summarize incomerateidx firmsrateidx unemployment cantfirmsrateidx wage shareunder20 shareold shareforeigners population leftstrength cinema university language metropolitan settlement forest agriculture
outreg2 using summary_independent_text.doc, replace sum(log) keep(incomerateidx firmsrateidx unemployment wage shareunder20 shareold shareforeigners population leftstrength cinema university language metropolitan settlement forest agriculture) title(Descriptive Statistics for independent variables) addnote("Note:",)
*END 3







			********4*Independent Variable details for tax index Descr. Statistics********
cd "/home/david/MEGA/Uni/Masterarbeit/Desciptive Statistics/"
capture drop if years == 2015
order id municipalities canton single* married* retired* incomerateidx totalrate* firmsrateidx unemployment cantfirmsrateidx wage under20 old foreigners leftstrength cinema university language metropolitan fte* firms* jobs*
set more off
set matsize 8000
foreach var of varlist ftetotal-logftelarge { // replace BS and GL by missings if not already done
	replace `var' = . if canton == "BS" | canton == "GL"
}
summarize single* married* retired* incomerateidx totalrate* firmsrateidx
outreg2 using summary_independent_appendix.doc, replace sum(log) keep(single* married* retired* totalrate*) title(Descriptive Statistics for independent variables) addnote("Note:",)
*END 4




			********5*Maps********
clear
cd "/home/david/MEGA/Uni/Masterarbeit/Data/Maps"
use "/home/david/MEGA/Uni/Masterarbeit/Data/database.dta"
save "/home/david/MEGA/Uni/Masterarbeit/Data/Maps/database.dta", replace
use "/home/david/MEGA/Uni/Masterarbeit/Data/Maps/database.dta"

*****Location: /Data/Maps/*****			
*****Official files downloaded from http://geostat.admin.ch/*****
*****Files: g2g16 (municipalities) and g2s16 (lakes)*****
*****Shp files contains the official points of each municipal polygon*****
clear
shp2dta using g2g16, database(chdatabase_2) coordinates(chcoordinates_2) genid(id) genc(c)replace
shp2dta using g2s16, database(lakesdb) coordinates(lakescoo) genid(id) genc(c) replace
use chdatabase_2, clear
drop Z* BZNR //drop some unnecessary variables
generate _ID = id // in coordinates : _ID is alphabetical but in the master database id is the OFS number, I use only the id from OFS
save chdatabase_2, replace
use chcoordinates_2, clear
merge m:1 _ID using chdatabase_2 //Merging the two database
keep GMDNR _ID _X _Y 
replace _ID = GMDNR //replacing the alphabetical id by the OFS number
drop GMDNR
sort _ID //sorting by _ID otherwise the map will not be right
save chcoordinates_2, replace

*Firms tax rate index
use "/home/david/MEGA/Uni/Masterarbeit/Data/Maps/database.dta", clear
generate GMDNR = id
merge m:1 GMDNR using "chdatabase_2.dta"
sort id
replace years = 2014 if _merge == 2
replace id = GMDNR if _merge == 2
replace firmsrateidx = round(firmsrateidx,.1)
spmap firmsrateidx using chcoordinates_2 if years == 2014, id(id) fcolor(Blues) ndfcolor(olive_teal) ///
clnumber(7) poly(data("lakescoo.dta") fcolor(gray)) line(data("chcoordinates_2.dta") color(black) size(0.1)) ///
legend(position(1) title("Tax rate index (in %)", size (2) position(1) justification(center))) legstyle(2)

*Income tax rate index
use "/home/david/MEGA/Uni/Masterarbeit/Data/Maps/database.dta", clear
generate GMDNR = id
merge m:1 GMDNR using "chdatabase_2.dta"
sort id
replace years = 2014 if _merge == 2
replace id = GMDNR if _merge == 2
replace incomerateidx = round(incomerateidx,.1)
spmap incomerateidx using chcoordinates_2 if years == 2014, id(id) fcolor(Reds) ndfcolor(olive_teal) ///
clnumber(7) poly(data("lakescoo.dta") fcolor(gray)) line(data("chcoordinates_2.dta") color(black) size(0.1)) ///
legend(position(1) title("Tax rate index (in %)", size (2) position(1) justification(center))) legstyle(2)
*END 5





			********6*One nice graphic********
use "/home/david/MEGA/Uni/Masterarbeit/Data/Maps/database.dta"
set more off
set matsize 8000
foreach var of varlist ftetotal-logftelarge {
	replace `var' = . if canton == "BS" | canton == "GL"
}
label variable firmsrateidx "Firms tax rate index (in %)"
label variable ftetotal "Total of full-time equivalent"
*FTE vs Firms rate index
twoway (scatter ftetotal firmsrateidx)(lfit ftetotal firmsrateidx) if years== 2014 & ftetotal < 3000, graphregion(color(white)) legend(off) ytitle("Full-time equivalent")
*END 6


*See results.do for the analysis*

			*********END Do-File*********
